=========================================
Descripción de la estructura del proyecto
=========================================

Tribus está dividido en varios paquetes de python, entre los que podemos mencionar:


.. automodule:: tribus.cli
   :members:

.. automodule:: tribus.web
   :members:

.. automodule:: tribus.common
   :members:
  
.. automodule:: tribus.config
   :members:

.. automodule:: tribus.tests
   :members:
 
.. automodule:: tribus.data
   :members: